@@ -2,12 +2,11 @@ from __future__ import print_function, division, absolute_import
 
 from distributed.deploy.ssh import SSHCluster
 import click
-import os
 
 from distributed.cli.utils import check_python_3
 
 
-@click.command(help = """Launch a distributed cluster over SSH. A 'dask-scheduler' process will run on the
+@click.command(help="""Launch a distributed cluster over SSH. A 'dask-scheduler' process will run on the
                          first host specified in [HOSTNAMES] or in the hostfile (unless --scheduler is specified
                          explicitly). One or more 'dask-worker' processes will be run each host in [HOSTNAMES] or
                          in the hostfile. Use command line flags to adjust how many dask-worker process are run on
@@ -17,7 +16,9 @@ from distributed.cli.utils import check_python_3
 @click.option('--scheduler-port', default=8786, type=int,
               help="Specify scheduler port number.  Defaults to port 8786.")
 @click.option('--nthreads', default=0, type=int,
-              help="Number of threads per worker process. Defaults to number of cores divided by the number of processes per host.")
+              help=("Number of threads per worker process. "
+                    "Defaults to number of cores divided by the number of "
+                    "processes per host."))
 @click.option('--nprocs', default=1, type=int,
               help="Number of worker processes per host.  Defaults to one.")
 @click.argument('hostnames', nargs=-1, type=str)
@@ -29,12 +30,16 @@ from distributed.cli.utils import check_python_3
               help="Port to use for SSH connections.")
 @click.option('--ssh-private-key', default=None, type=str,
               help="Private key file to use for SSH connections.")
-
+@click.option('--nohost', is_flag=True,
+              help="Do not pass the hostname to the worker.")
 @click.option('--log-directory', default=None, type=click.Path(exists=True),
-              help="Directory to use on all cluster nodes for the output of dask-scheduler and dask-worker commands.")
+              help=("Directory to use on all cluster nodes for the output of "
+                    "dask-scheduler and dask-worker commands."))
+@click.option('--remote-python', default=None, type=str,
+              help="Path to Python on remote nodes.")
 @click.pass_context
 def main(ctx, scheduler, scheduler_port, hostnames, hostfile, nthreads, nprocs,
-          ssh_username, ssh_port, ssh_private_key, log_directory):
+         ssh_username, ssh_port, ssh_private_key, nohost, log_directory, remote_python):
     try:
         hostnames = list(hostnames)
         if hostfile:
@@ -50,14 +55,14 @@ def main(ctx, scheduler, scheduler_port, hostnames, hostfile, nthreads, nprocs,
         exit(1)
 
     c = SSHCluster(scheduler, scheduler_port, hostnames, nthreads, nprocs,
-                ssh_username, ssh_port, ssh_private_key, log_directory)
+                   ssh_username, ssh_port, ssh_private_key, nohost, log_directory, remote_python)
 
     import distributed
     print('\n---------------------------------------------------------------')
     print('                 Dask.distributed v{version}\n'.format(version=distributed.__version__))
     print('Worker nodes:'.format(n=len(hostnames)))
     for i, host in enumerate(hostnames):
-        print('  {num}: {host}'.format(num = i, host = host))
+        print('  {num}: {host}'.format(num=i, host=host))
     print('\nscheduler node: {addr}:{port}'.format(addr=scheduler, port=scheduler_port))
     print('---------------------------------------------------------------\n\n')
 
@@ -74,5 +79,6 @@ def go():
     check_python_3()
     main()
 
+
 if __name__ == '__main__':
-    start()
+    go()
