@@ -10,7 +10,7 @@ from tornado import gen
 
 from .progress import AllProgress
 
-from ..core import connect, write, coerce_to_address
+from ..core import connect, coerce_to_address
 from ..scheduler import Scheduler
 from ..utils import key_split
 from ..worker import dumps_function
@@ -21,19 +21,28 @@ logger = logging.getLogger(__name__)
 task_stream_palette = list(viridis(25))
 random.shuffle(task_stream_palette)
 
+
 def counts(scheduler, allprogress):
     return merge({'all': valmap(len, allprogress.all),
                   'nbytes': allprogress.nbytes},
                  {state: valmap(len, allprogress.state[state])
-                     for state in ['memory', 'erred', 'released']})
+                     for state in ['memory', 'erred', 'released', 'processing']})
 
 
 counter = itertools.count()
-@memoize
+
+_incrementing_index_cache = dict()
+
+
+@memoize(cache=_incrementing_index_cache)
 def incrementing_index(o):
     return next(counter)
 
 
+def color_of(o, palette=task_stream_palette):
+    return palette[incrementing_index(o) % len(palette)]
+
+
 @gen.coroutine
 def progress_stream(address, interval):
     """ Open a TCP connection to scheduler, receive progress messages
@@ -53,14 +62,14 @@ def progress_stream(address, interval):
     >>> stream = yield eventstream('127.0.0.1:8786', 0.100)  # doctest: +SKIP
     >>> print(yield read(stream))  # doctest: +SKIP
     """
-    ip, port = coerce_to_address(address, out=tuple)
-    stream = yield connect(ip, port)
-    yield write(stream, {'op': 'feed',
-                         'setup': dumps_function(AllProgress),
-                         'function': dumps_function(counts),
-                         'interval': interval,
-                         'teardown': dumps_function(Scheduler.remove_plugin)})
-    raise gen.Return(stream)
+    address = coerce_to_address(address)
+    comm = yield connect(address)
+    yield comm.write({'op': 'feed',
+                      'setup': dumps_function(AllProgress),
+                      'function': dumps_function(counts),
+                      'interval': interval,
+                      'teardown': dumps_function(Scheduler.remove_plugin)})
+    raise gen.Return(comm)
 
 
 def nbytes_bar(nbytes):
@@ -97,8 +106,7 @@ def nbytes_bar(nbytes):
         d['left'].append(left)
         d['right'].append(right)
         d['center'].append(center)
-        d['color'].append(task_stream_palette[incrementing_index(name)
-                                            % len(task_stream_palette)])
+        d['color'].append(color_of(name))
         d['name'].append(name)
         if right - left > 0.1:
             d['text'].append(name)
@@ -114,7 +122,8 @@ def progress_quads(msg, nrows=8, ncols=3):
     >>> msg = {'all': {'inc': 5, 'dec': 1, 'add': 4},
     ...        'memory': {'inc': 2, 'dec': 0, 'add': 1},
     ...        'erred': {'inc': 0, 'dec': 1, 'add': 0},
-    ...        'released': {'inc': 1, 'dec': 0, 'add': 1}}
+    ...        'released': {'inc': 1, 'dec': 0, 'add': 1},
+    ...        'processing': {'inc': 1, 'dec': 0, 'add': 2}}
 
     >>> progress_quads(msg, nrows=2)  # doctest: +SKIP
     {'name': ['inc', 'add', 'dec'],
@@ -125,10 +134,12 @@ def progress_quads(msg, nrows=8, ncols=3):
      'released': [1, 1, 0],
      'memory': [2, 1, 0],
      'erred': [0, 0, 1],
+     'processing': [1, 0, 2],
      'done': ['3 / 5', '2 / 4', '1 / 1'],
      'released-loc': [.2/.9, .25 / 0.9, 1],
      'memory-loc': [3 / 5 / .9, .5 / 0.9, 1],
-     'erred-loc': [3 / 5 / .9, .5 / 0.9, 1.9]}
+     'erred-loc': [3 / 5 / .9, .5 / 0.9, 1.9],
+     'processing-loc': [4 / 5, 1 / 1, 1]}}
     """
     width = 0.9
     names = sorted(msg['all'], key=msg['all'].get, reverse=True)
@@ -143,71 +154,80 @@ def progress_quads(msg, nrows=8, ncols=3):
     d['right'] = [i // nrows + width for i in range(n)]
     d['top'] = [-(i % nrows) for i in range(n)]
     d['bottom'] = [-(i % nrows) - 0.8 for i in range(n)]
-    d['color'] = [task_stream_palette[incrementing_index(name)
-                                    % len(task_stream_palette)]
-                    for name in names]
+    d['color'] = [color_of(name) for name in names]
 
     d['released-loc'] = []
     d['memory-loc'] = []
     d['erred-loc'] = []
+    d['processing-loc'] = []
     d['done'] = []
-    for r, m, e, a, l in zip(d['released'], d['memory'],
-                             d['erred'], d['all'], d['left']):
+    for r, m, e, p, a, l in zip(d['released'], d['memory'], d['erred'],
+                                d['processing'], d['all'], d['left']):
         rl = width * r / a + l
         ml = width * (r + m) / a + l
         el = width * (r + m + e) / a + l
+        pl = width * (p + r + m + e) / a + l
         done = '%d / %d' % (r + m + e, a)
         d['released-loc'].append(rl)
         d['memory-loc'].append(ml)
         d['erred-loc'].append(el)
+        d['processing-loc'].append(pl)
         d['done'].append(done)
 
     return d
 
+
+def color_of_message(msg):
+    if msg['status'] == 'OK':
+        split = key_split(msg['key'])
+        return color_of(split)
+    else:
+        return 'black'
+
+
+colors = {'transfer': 'red',
+          'disk-write': 'orange',
+          'disk-read': 'orange',
+          'deserialize': 'gray',
+          'compute': color_of_message}
+
+
+alphas = {'transfer': 0.4,
+          'compute': 1,
+          'deserialize': 0.4,
+          'disk-write': 0.4,
+          'disk-read': 0.4}
+
+
+prefix = {'transfer': 'transfer-',
+          'disk-write': 'disk-write-',
+          'disk-read': 'disk-read-',
+          'deserialize': 'deserialize-',
+          'compute': ''}
+
+
 def task_stream_append(lists, msg, workers, palette=task_stream_palette):
-    start, stop = msg['compute_start'], msg['compute_stop']
-    lists['start'].append((start + stop) / 2 * 1000)
-    lists['duration'].append(1000 * (stop - start))
     key = msg['key']
     name = key_split(key)
-    if msg['status'] == 'OK':
-        color = palette[incrementing_index(name) % len(palette)]
-    else:
-        color = 'black'
-    lists['key'].append(key)
-    lists['name'].append(name)
-    lists['color'].append(color)
-    lists['alpha'].append(1)
-    lists['worker'].append(msg['worker'])
+    startstops = msg.get('startstops', [])
 
-    worker_thread = '%s-%d' % (msg['worker'], msg['thread'])
-    lists['worker_thread'].append(worker_thread)
-    if worker_thread not in workers:
-        workers[worker_thread] = len(workers)
-    lists['y'].append(workers[worker_thread])
+    for action, start, stop in startstops:
+        color = colors[action]
+        if type(color) is not str:
+            color = color(msg)
 
-    if msg.get('transfer_start') is not None:
-        start, stop = msg['transfer_start'], msg['transfer_stop']
         lists['start'].append((start + stop) / 2 * 1000)
         lists['duration'].append(1000 * (stop - start))
-
         lists['key'].append(key)
-        lists['name'].append('transfer-to-' + name)
+        lists['name'].append(prefix[action] + name)
+        lists['color'].append(color)
+        lists['alpha'].append(alphas[action])
         lists['worker'].append(msg['worker'])
-        lists['color'].append('#FF0020')
-        lists['alpha'].append('0.4')
+
+        worker_thread = '%s-%d' % (msg['worker'], msg['thread'])
         lists['worker_thread'].append(worker_thread)
+        if worker_thread not in workers:
+            workers[worker_thread] = len(workers) / 2
         lists['y'].append(workers[worker_thread])
 
-    if msg.get('disk_load_start') is not None:
-        start, stop = msg['disk_load_start'], msg['disk_load_stop']
-        lists['start'].append((start + stop) / 2 * 1000)
-        lists['duration'].append(1000 * (stop - start))
-
-        lists['key'].append(key)
-        lists['name'].append('disk-load-' + name)
-        lists['worker'].append(msg['worker'])
-        lists['color'].append('#FF2000')
-        lists['alpha'].append('0.4')
-        lists['worker_thread'].append(worker_thread)
-        lists['y'].append(workers[worker_thread])
+    return len(startstops)
