@@ -38,7 +38,7 @@ from tornado import gen, queues
 from tornado.gen import TimeoutError
 from tornado.ioloop import IOLoop
 
-from .compatibility import PY3, iscoroutinefunction
+from .compatibility import PY3, iscoroutinefunction, Empty
 from .config import config, initialize_logging
 from .core import connect, rpc, CommClosedError
 from .metrics import time
@@ -529,8 +529,11 @@ def cluster(nworkers=2, nanny=False, worker_kwargs={}, active_rpc_timeout=1,
 
             for worker in workers:
                 worker['proc'].start()
-            for worker in workers:
-                worker['address'] = worker['queue'].get()
+            try:
+                for worker in workers:
+                    worker['address'] = worker['queue'].get(timeout=5)
+            except Empty:
+                raise pytest.xfail.Exception("Worker failed to start in test")
 
             saddr = scheduler_q.get()
 
@@ -700,6 +703,8 @@ def gen_cluster(ncores=[('127.0.0.1', 1), ('127.0.0.1', 2)],
         start
         end
     """
+    config['nanny-start-timeout'] = '5s'
+    config['connect-timeout'] = '5s'
     worker_kwargs = merge({'memory_limit': TOTAL_MEMORY, 'death_timeout': 5},
                           worker_kwargs)
 
@@ -738,7 +743,11 @@ def gen_cluster(ncores=[('127.0.0.1', 1), ('127.0.0.1', 2)],
                                              asynchronous=True)
                             args = [c] + args
                         try:
-                            result = yield func(*args)
+                            future = func(*args)
+                            if timeout:
+                                future = gen.with_timeout(timedelta(seconds=timeout),
+                                                          future)
+                            result = yield future
                             if s.validate:
                                 s.validate_state()
                         finally:
@@ -750,7 +759,7 @@ def gen_cluster(ncores=[('127.0.0.1', 1), ('127.0.0.1', 2)],
 
                         raise gen.Return(result)
 
-                    result = loop.run_sync(coro, timeout=timeout)
+                    result = loop.run_sync(coro, timeout=timeout * 2 if timeout else timeout)
 
             for w in workers:
                 if getattr(w, 'data', None):
@@ -1065,6 +1074,17 @@ def new_config(new_config):
         initialize_logging(config)
 
 
+@contextmanager
+def new_environment(changes):
+    saved_environ = os.environ.copy()
+    os.environ.update(changes)
+    try:
+        yield
+    finally:
+        os.environ.clear()
+        os.environ.update(saved_environ)
+
+
 @contextmanager
 def new_config_file(c):
     """
